@@ -12,10 +12,12 @@
 #define KQUICKSTYLEITEM_P_H
 
 #include "kquickpadding_p.h"
+#include <QImage>
 #include <QPointer>
-#include <QtGui/qimage.h>
-#include <QtQuick/qquickimageprovider.h>
-#include <QtQuick/qquickitem.h>
+#include <QQuickImageProvider>
+#include <QQuickItem>
+
+#include <qqmlregistration.h>
 
 #include <memory>
 
@@ -25,8 +27,11 @@ class QStyle;
 
 namespace Kirigami
 {
+namespace Platform
+{
 class PlatformTheme;
 }
+}
 
 class QQuickTableRowImageProvider1 : public QQuickImageProvider
 {
@@ -41,6 +46,7 @@ public:
 class KQuickStyleItem : public QQuickItem
 {
     Q_OBJECT
+    QML_NAMED_ELEMENT(StyleItem)
 
     Q_PROPERTY(KQuickPadding *border READ border CONSTANT)
 
@@ -49,7 +55,7 @@ class KQuickStyleItem : public QQuickItem
     Q_PROPERTY(bool flat READ flat WRITE setFlat NOTIFY flatChanged)
     Q_PROPERTY(bool active READ active WRITE setActive NOTIFY activeChanged)
     Q_PROPERTY(bool selected READ selected WRITE setSelected NOTIFY selectedChanged)
-    Q_PROPERTY(bool hasFocus READ hasFocus WRITE sethasFocus NOTIFY hasFocusChanged)
+    Q_PROPERTY(bool hasFocus READ hasFocus WRITE setHasFocus NOTIFY hasFocusChanged)
     Q_PROPERTY(bool on READ on WRITE setOn NOTIFY onChanged)
     Q_PROPERTY(bool hover READ hover WRITE setHover NOTIFY hoverChanged)
     Q_PROPERTY(bool horizontal READ horizontal WRITE setHorizontal NOTIFY horizontalChanged)
@@ -266,7 +272,7 @@ public:
             Q_EMIT selectedChanged();
         }
     }
-    void sethasFocus(bool focus)
+    void setHasFocus(bool focus)
     {
         if (m_focus != focus) {
             m_focus = focus;
@@ -294,6 +300,7 @@ public:
     {
         if (m_horizontal != horizontal) {
             m_horizontal = horizontal;
+            updateSizeHint();
             polish();
             Q_EMIT horizontalChanged();
         }
@@ -360,11 +367,19 @@ public:
     {
         if (m_activeControl != str) {
             m_activeControl = str;
+            // Slider is the only type whose size hints react to active control changes.
+            switch (m_itemType) {
+            case Slider:
+                updateSizeHint();
+                break;
+            default:
+                break;
+            }
             polish();
             Q_EMIT activeControlChanged();
         }
     }
-    void setHints(const QVariantMap &str);
+    void setHints(const QVariantMap &hints);
     void setProperties(const QVariantMap &props)
     {
         if (m_properties != props) {
@@ -389,11 +404,11 @@ public:
     }
     void setContentHeight(int arg);
 
-    virtual void initStyleOption();
+    void initStyleOption();
     void resolvePalette();
 
-    int leftPadding() const;
     int topPadding() const;
+    int leftPadding() const;
     int rightPadding() const;
     int bottomPadding() const;
 
@@ -434,6 +449,9 @@ public Q_SLOTS:
     QString elidedText(const QString &text, int elideMode, int width);
     bool hasThemeIcon(const QString &) const;
 
+private Q_SLOTS:
+    void updateFocusReason();
+
 Q_SIGNALS:
     void elementTypeChanged();
     void textChanged();
@@ -477,20 +495,17 @@ protected:
     bool eventFilter(QObject *watched, QEvent *event) override;
     void itemChange(QQuickItem::ItemChange change, const QQuickItem::ItemChangeData &value) override;
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    void geometryChanged(const QRectF &newGeometry, const QRectF &oldGeometry) override;
-#else
     void geometryChange(const QRectF &newGeometry, const QRectF &oldGeometry) override;
-#endif
 
 private:
+    int padding(Qt::Edge edge) const;
     QIcon iconFromIconProperty() const;
     const char *classNameForItem() const;
     qreal baselineOffset();
     void styleChanged();
 
 protected:
-    Kirigami::PlatformTheme *m_theme = nullptr;
+    Kirigami::Platform::PlatformTheme *m_theme = nullptr;
     QStyleOption *m_styleoption;
     QPointer<QQuickItem> m_control;
     QPointer<QWindow> m_window;
@@ -528,7 +543,8 @@ protected:
     int m_textureWidth;
     int m_textureHeight;
 
-    Qt::FocusReason m_lastFocusReason;
+    QMetaProperty m_focusReasonProperty;
+    Qt::FocusReason m_focusReason;
 
     QImage m_image;
     KQuickPadding m_border;
